@@ -65,6 +65,8 @@ def procesamiento_aseguradoras(date_port, port_name, ruta, ruta_precia, portfoli
 
     Columnas = pd.read_csv(ruta+'\Equivalencias\SABANA_INVENTARIO.csv', sep=';', header=0)
     Calificaciones = pd.read_csv(ruta+'\Equivalencias\CALIFICACIONES.csv', sep=';', header=0)
+    coupFreq = pd.read_csv(ruta+'\Equivalencias\coupFreq.csv', sep=';', header=0)
+    dateConv = pd.read_csv(ruta+'\Equivalencias\dateConv.csv', sep=';', header=0)
     Nemos = pd.read_excel(ruta+'\Equivalencias\\NEMOS-ISIN.xlsx')
     Portafolio = pd.read_excel(ruta+'\Insumos\\'+Tipoportafolio+Fecha+'.xlsx')
     Portafolio = Portafolio.replace("[NULL]", np.nan)
@@ -74,8 +76,7 @@ def procesamiento_aseguradoras(date_port, port_name, ruta, ruta_precia, portfoli
     Precia.columns=Precia.columns.str.replace(u"á", "a").str.replace(u"é", "e").str.replace(u"í", "i").str.replace(u"ó", "o").str.replace(u"ú", "u")
 
     Columnas351=Columnas["351"].dropna().unique().tolist()
-    Columnasprecia=Columnas["PRECIA"].dropna().unique().tolist()
-    Portafolio=Portafolio.drop([0],axis=0)
+    Columnasprecia=Columnas["PRECIA"].dropna().unique().tolist()    
     Portafolio=Portafolio[Columnas351]
     Precia=Precia[Columnasprecia]
 
@@ -179,6 +180,7 @@ def procesamiento_aseguradoras(date_port, port_name, ruta, ruta_precia, portfoli
     Portafolio = Portafolio.drop(['cpnRateType'], axis=1)    
     Portafolio = Portafolio.drop(['margin'], axis=1)
 
+
     # Se añade liquidez u otros campos de ser necesario.
     if add_rows is not None:
         for k in add_rows.copy().keys():
@@ -190,8 +192,9 @@ def procesamiento_aseguradoras(date_port, port_name, ruta, ruta_precia, portfoli
         Portafolio = Portafolio.append(add_rows).reset_index(drop=True)
 
     # Formateo columnas de fechas.
-    Portafolio['issueDt'] = pd.to_datetime(Portafolio['issueDt'], format='%d%m%Y').dt.strftime("%d/%m/%Y")
-    Portafolio['maturity'] = pd.to_datetime(Portafolio['maturity'], format='%d%m%Y').dt.strftime("%d/%m/%Y")
+    Portafolio['issueDt'] = pd.to_datetime(Portafolio['issueDt'], format='%d%m%Y').dt.strftime("%Y-%m-%d")
+    Portafolio['maturity'] = pd.to_datetime(Portafolio['maturity'], format='%d%m%Y').dt.strftime("%Y-%m-%d")
+    
 
     # Completo días al venc. con NA.
     Portafolio=Portafolio.astype({'daysToMaturity':'float'})
@@ -227,6 +230,22 @@ def procesamiento_aseguradoras(date_port, port_name, ruta, ruta_precia, portfoli
     Portafolio = pd.merge(Portafolio, Nemos[['assetId', 'cpnFirstActual', 'cpnRateType']], how='left', on='assetId')
     Portafolio['cpnType'] = ['F' if iR == 'FS' else 'T' if iR != 'FS' and iR is not np.nan else np.nan for iR in Portafolio['indexRate']]
 
+    # Cruzo con valores coupFreq.
+    coupFreq['idCoupFreq'] = coupFreq['idCoupFreq'].astype('Int64')
+    Portafolio['coupFreq'] = Portafolio['coupFreq'].astype('Int64')
+    coupFreq.rename(columns={'coupFreq': 'coupFreqValue'}, inplace=True)
+    Portafolio = pd.merge(Portafolio, coupFreq, how='left', left_on='coupFreq', right_on='idCoupFreq')
+    Portafolio['coupFreq'] = Portafolio['coupFreqValue']
+
+    # Cruzo con valores dateConv.
+    Portafolio['dateConv'] = Portafolio['dateConv'].astype('Int64')
+    dateConv['idDateConv'] = dateConv['idDateConv'].astype('Int64')
+    dateConv.rename(columns={'dateConv': 'dateConvValue'}, inplace=True)
+    Portafolio = pd.merge(Portafolio, dateConv, how='left', left_on='dateConv', right_on='idDateConv')
+    Portafolio['dateConv'] = Portafolio['dateConvValue']
+
+    Portafolio = Portafolio.drop(['idCoupFreq', 'X', 'coupFreqValue', 'idDateConv', 'dateConvValue'], axis=1)
+
     # Agrego Banda para calculo de margin.
     labels, bins_ini, bins_fin = [], [], []
     for k, v in dictDiasVcto.items():
